@@ -513,8 +513,7 @@ PackageList Backend::search(const QString &searchString) const
 {
     Q_D(const Backend);
 
-    if (d->xapianTimeStamp == 0) {
-        qDebug() << "Search index error, no timestamp";
+    if (d->xapianTimeStamp == 0 || !d->xapianDatabase) {
         return QApt::PackageList();
     }
 
@@ -660,6 +659,17 @@ bool Backend::isBroken() const
     return false;
 }
 
+QDateTime Backend::timeCacheLastUpdated() const
+{
+    QDateTime sinceUpdate;
+
+    QFileInfo updateStamp("/var/lib/apt/periodic/update-success-stamp");
+    if (!updateStamp.exists())
+        return sinceUpdate;
+
+    return updateStamp.lastModified();
+}
+
 bool Backend::xapianIndexNeedsUpdate() const
 {
     Q_D(const Backend);
@@ -686,6 +696,7 @@ bool Backend::openXapianIndex()
 
     if(d->xapianDatabase) {
         delete d->xapianDatabase;
+        d->xapianDatabase = 0;
     }
     try {
         d->xapianDatabase = new Xapian::Database("/var/lib/apt-xapian-index/index");
